Name:           gpick
Version:        0.2.5
Release:        %mkrel 6
Summary:        Advanced color picker written in C++ using GTK+ toolkit
License:        BSD
Group:          Graphics/Utilities
URL:            http://code.google.com/p/gpick/
Source0:        http://gpick.googlecode.com/files/%{name}_%{version}.tar.gz
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(lua) >= 5.2
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  scons
BuildRequires:  boost-devel
BuildRequires:  flex

%description
Gpick is an advanced color picker written in C++ using GTK+ toolkit.
Its main features are:
    - Create palettes from images
    - Color scheme creation tools
    - Fast color picking
    - Magnification
    - Colors automatically named
        + Closest color name is found using CIE94 color difference function,
          which is closer to the way humans interpret color differences, than
          difference of red, green and blue color amounts 
    - Export to following formats
        + Inkscape/Gimp Palette (*.gpl)
        + Adobe Swatch Exchange (*.ase)
        + Alias/WaveFront Material (*.mtl) 
    - Import from following formats:
        + Inkscape/Gimp Palette (*.gpl)
        + Adobe Swatch Exchange (*.ase) 
    - Picked colors can be copied to clipboard in multiple formats
        + Hexadecimal notation - #rrggbb
        + Functional RGB notation - rgb(red, green, blue)
        + Functional HSL notation - hsl(hue, saturation, lightness)
        + Custom conversions can be done, but requires some Lua language
          knowledge 
    - Oversampling with five falloff types
        + Multiple pixel values are averaged to help picking colors from
          sources with noise, patterns and etc, where each pixel is different
          and overall color is produced by different amounts of particular
          color 
    - Mix two or more colors using variable number of steps and different
      mixing types
    - Create lightness and/or saturation variations
    - Create harmonious colors
    - Create color schemes 

%prep
%setup -q -n %{name}_%{version}

# Delete external libraries and only use system dependencies to build GPick
rm -rf extern
sed -i -e '/extern_libs/d' SConscript
echo "INTERNAL_EXPAT=False" >> user-config.py
echo "INTERNAL_LUA=False" >> user-config.py
echo "LOCALEDIR=\"%{_datadir}/locale\"" >> user-config.py

%build
#nothing

%install
%setup_compile_flags
%scons install DESTDIR=%{buildroot}%{_prefix}

rm -rf %{buildroot}%{_docdir}/%{name}

%find_lang %{name}

%files -f %{name}.lang
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%{_iconsdir}/hicolor/*/apps/gpick.*
%{_mandir}/man1/gpick.1.*


%changelog
* Mon Feb 08 2016 umeabot <umeabot> 0.2.5-6.mga6
+ Revision: 944403
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.2.5-5.mga5
+ Revision: 742312
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.2.5-4.mga5
+ Revision: 679912
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.2.5-3.mga4
+ Revision: 529451
- Mageia 4 Mass Rebuild

* Tue Jul 09 2013 fwang <fwang> 0.2.5-2.mga4
+ Revision: 451863
- rebuild for new boost

* Sun Jul 07 2013 wally <wally> 0.2.5-1.mga4
+ Revision: 450913
- new version 0.2.5
- use system lua and expat (from Fedora)
- clean .spec a bit

* Sat Jan 12 2013 umeabot <umeabot> 0.2.4-4.mga3
+ Revision: 352522
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 barjac <barjac> 0.2.4-3.mga3
+ Revision: 343266
- update group - again

* Wed Jan 02 2013 barjac <barjac> 0.2.4-2.mga3
+ Revision: 337845
- update group

* Wed Sep 14 2011 obgr_seneca <obgr_seneca> 0.2.4-1.mga2
+ Revision: 143536
- imported package gpick


* Fri Aug 19 2011 Oliver Burger <oliver.bgr@googlemail.com> 0.2.4-1.mga1
- initial build for Mageia
